aboutsummaryrefslogtreecommitdiff
path: root/src/args.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/args.rs')
-rw-r--r--src/args.rs14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/args.rs b/src/args.rs
index fb5d6c1..7004791 100644
--- a/src/args.rs
+++ b/src/args.rs
@@ -17,9 +17,9 @@ pub struct Args {
#[arg(short = 'I', value_name = "interface")]
pub interface: Option<String>,
- /// number of seconds to wait between 2 pings
- #[arg(short = 'i', value_name = "seconds")]
- pub seconds: Option<f32>,
+ /// number of milliseconds to wait between 2 pings
+ #[arg(short = 'i', value_name = "milliseconds")]
+ pub interval: Option<u32>,
/// the Time-to-live
#[arg(short = 't', long = "ttl", value_name = "TTL")]
@@ -29,12 +29,12 @@ pub struct Args {
#[arg(short = 's', long = "stats", action = ArgAction::SetTrue)]
pub stats: bool,
- /// Print the Help line
- #[arg(short = 'H', action = ArgAction::Help, required = false)]
- pub help: Option<bool>,
+ /// Print the legende line
+ #[arg(short = 'l', long = "legende", action = ArgAction::SetTrue)]
+ pub legende: bool,
/// Print the remainder line
- #[arg(short = 'l', long = "remainder", action = ArgAction::SetTrue)]
+ #[arg(short = 'r', long = "remainder", action = ArgAction::SetTrue)]
pub remainder: bool,
/// Target IP address